@@ -25,7 +25,7 @@ class CallbackMapManager(models.Manager):
         return self.get_query_set().filter(query)
 
     def all_expired_callbacks(self, days=7, delete_errors=False):
-        use_date = timezone.now().date() - datetime.timedelta(days=days)
+        use_date = timezone.now() - datetime.timedelta(days=days)
         query = Q(is_active=False) 
         if not delete_errors:
             query &= Q(is_error=False)
