@@ -1,5 +1,5 @@
-import datetime
 from django.db import models
+from django.utils import timezone
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from callback.managers import CallbackMapManager
@@ -16,8 +16,8 @@ class CallbackMap(models.Model):
     is_error = models.BooleanField(default=False)
     error_msg = models.TextField(blank=True)
 
-    created_on = models.DateTimeField(default=datetime.datetime.now)
-    updated_on = models.DateTimeField(default=datetime.datetime.now)
+    created_on = models.DateTimeField(default=timezone.now)
+    updated_on = models.DateTimeField(default=timezone.now)
 
     objects = CallbackMapManager()
 
@@ -43,5 +43,5 @@ class CallbackMap(models.Model):
 
     def save(self, *args, **kwargs):
         if self.id:
-            self.updated_on = datetime.datetime.now()
+            self.updated_on = timezone.now()
         super(CallbackMap, self).save(*args, **kwargs)
